@@ -1,9 +1,9 @@
 /***************************************************************************
                            tabulardialog.cpp
 ----------------------------------------------------------------------------
-    date                 : Jul 23 2005
-    version              : 0.20
-    copyright            : (C) 2005 by Holger Danielsson
+    date                 : Sep 17 2006
+    version              : 0.26
+    copyright            : (C) 2005-2006 by Holger Danielsson
     email                : holger.danielsson@t-online.de
  ***************************************************************************/
 
@@ -832,36 +832,28 @@ void TabularTable::setAlignment(int row,int col,int align)
 		updateCell(row,col);
 }
 
-void TabularTable::setColspan(int row,int col1,int col2,bool savetext)
+void TabularTable::setColspan(int row,int col1,int col2,int numcols,const QString &text)
 {
-	QString s;
-	
 	//kdDebug() << "set colspan " << col1 << "-" << col2 << " "<< endl; 
-	for ( int col=col1; col<=col2; ++col ) 
+	for ( int col=col1; col<=col2; ) 
 	{
-		QTableItem *olditem = item(row,col);
-		if ( olditem ) {
-			QString temp = olditem->text().stripWhiteSpace(); 
-			if ( savetext && !temp.isEmpty() ) 
-			{
-				if ( ! s.isEmpty() )
-					s += " ";
-				s += temp;
-			}
-			delete olditem;
+		TabularItem *olditem = dynamic_cast<TabularItem*>( item(row,col) );
+		if ( olditem ) 
+		{
+			if ( col != col1 )
+				delete olditem;
+			col += olditem->colSpan();
+		}
+		else
+		{
+			col++;
 		}
 	}
 	
-	// there is definitely no old item
-	TabularItem *newitem = new TabularItem(this);
-	setItem(row,col1,newitem);
-	newitem->setSpan(1,col2-col1+1);
-	//newitem->m_data.bgcolor = QColor(Qt::yellow);
-	
-	if ( ! s.isEmpty() ) 
-	{
-		newitem->setText(s);
-	}
+	// only the leftmost item exists 
+	TabularItem *cellitem = cellItem(row,col1);
+	cellitem->setText(text);
+	cellitem->setSpan(1,numcols);
 }
 
 bool TabularTable::isMulticolumn(int row,int col)
@@ -1198,8 +1190,7 @@ void TabularTable::slotContextMenuClicked(int,int,const QPoint &)
 
 	if ( ! getCurrentSelection(m_x1,m_y1,m_x2,m_y2) )
 		return;
-	//kdDebug() << "mc click " << m_x1 << " " << m_y1 << " " << m_x2 << " " << m_y2 << endl;
-	
+
 	// create popup menu
 	m_cellpopup = createPopupMenu();
 	
@@ -1217,8 +1208,13 @@ void TabularTable::slotContextMenuClicked(int,int,const QPoint &)
 		} 
 		else if ( m_x2 > m_x1 ) 
 		{
-			m_cellpopup->insertItem( i18n("Set Multicolumn"));
-			m_cellpopup->insertSeparator();
+			TabularItem *cellitem1 = dynamic_cast<TabularItem*>( item(m_y1,m_x1) );
+			TabularItem *cellitem2 = dynamic_cast<TabularItem*>( item(m_y2,m_x2) );
+			if ( (!cellitem1 && !cellitem2) || (cellitem1!=cellitem2) )
+			{
+				m_cellpopup->insertItem( i18n("Set Multicolumn"));
+				m_cellpopup->insertSeparator();
+			}
 		}
 	}
 	
@@ -1227,6 +1223,7 @@ void TabularTable::slotContextMenuClicked(int,int,const QPoint &)
 	
 	connect(m_cellpopup,SIGNAL(activated(int)),this,SLOT(slotCellPopupActivated(int)));
 	m_cellpopup->exec( QCursor::pos() );
+	clearSelection();
 }
 
 
@@ -1268,16 +1265,22 @@ void TabularTable::cellPopupEdit()
 void TabularTable::cellPopupSetMulticolumn()
 {
 	//kdDebug() << "slotContextMenuSetMulticolumn" << endl;
-		
+	//kdDebug() << "set mc " << m_x1 << " " << m_y1 << "   " << m_x2 << " " << m_y2 << endl;
+
 	if ( m_y1==m_y2 && m_x2>m_x1) 
 	{
-		bool savetext = false;
-		if ( ! isRowEmpty(m_y1,m_x1,m_x2) ) 
+		// get full cell range including possible multicolumn cells
+		int xl,xr;
+		getCellRange(m_y1,m_x1,m_x2,xl,xr);
+
+		QString s = getCellRangeText(m_y1,xl,xr);
+		if ( ! s.isEmpty() ) 
 		{
 			QString message  = i18n("Concat all text to the new multicolumn cell?");
-			savetext = ( KMessageBox::questionYesNo(this,message,i18n("Save Text")) == KMessageBox::Yes ); 
+			if ( KMessageBox::questionYesNo(this,message,i18n("Save Text")) != KMessageBox::Yes )
+				s = QString::null;
 		}
-		setColspan(m_y1,m_x1,m_x2,savetext);
+		setColspan(m_y1,xl,xr,xr-xl+1,s);
 		// update();
 	}
 }
@@ -1285,20 +1288,24 @@ void TabularTable::cellPopupSetMulticolumn()
 void TabularTable::cellPopupBreakMulticolumn()
 {
 	//kdDebug() << "slotContextMenuBreakMulticolumn" << endl;
+	//kdDebug() << "set mc " << m_x1 << " " << m_y1 << " " << m_x2 << " " << m_y2 << endl;
 	
 	if ( m_x1==m_x2 && m_y1==m_y2 ) 
 	{
-		TabularItem *cellitem = dynamic_cast<TabularItem*>( item(m_y1,m_x1) );
-		if ( cellitem && KMessageBox::questionYesNo(this,
-			                             i18n("Transfer text and all attributes of the multicolumn cell to the leftmost of the separated cell?"),
-			                             i18n("Shrink Multicolumn")) == KMessageBox::Yes ) 
-		{ 
-			cellitem->setSpan(m_y1,1);
-		} 
-		else 
+		// get full cell range including possible multicolumn cells
+		int xl,xr;
+		getCellRange(m_y1,m_x1,m_x2,xl,xr);
+
+		QString s = getCellRangeText(m_y1,xl,xr);
+		if ( ! s.isEmpty() ) 
 		{
-			delete cellitem;
+			if ( KMessageBox::questionYesNo(this,
+			               i18n("Transfer text and all attributes of the multicolumn cell to the leftmost of the separated cell?"),
+			               i18n("Shrink Multicolumn")) != KMessageBox::Yes )
+				s = QString::null;
 		}
+
+		setColspan(m_y1,xl,xr,1,s);
 	}
 }
 
@@ -1307,6 +1314,59 @@ void TabularTable::cellPopupAlign(int align)
 	setCellrangeAlignment(m_x1,m_y1,m_x2,m_y2,align);
 }
 
+// get real cell range including possible multicolumn cells
+void TabularTable::getCellRange(int row,int col1, int col2, int &xl, int &xr)
+{
+	// search the first cell of this range
+	xl = col1;
+	TabularItem *cellitem1 = dynamic_cast<TabularItem*>( item(row,col1) );
+	if ( cellitem1 && cellitem1->isMulticolumn() )
+	{
+		for ( int col=col1-1; col>=0; --col )
+		{
+			TabularItem *cellitem = dynamic_cast<TabularItem*>( item(row,col) );
+			if ( cellitem == cellitem1 )
+				xl = col;
+			else
+				break;
+		} 
+	}
+
+	// search the last cell of this range
+	xr = col2;
+	TabularItem *cellitem2 = dynamic_cast<TabularItem*>( item(row,col2) );
+	if ( cellitem2 && cellitem2->isMulticolumn() )
+	{
+		for ( int col=col2+1; col<numCols(); ++col )
+		{
+			TabularItem *cellitem = dynamic_cast<TabularItem*>( item(row,col) );
+			if ( cellitem == cellitem2 )
+				xr = col;
+			else
+				break;
+		} 
+	}
+}
+
+// get text from real cell range including possible multicolumn cells
+QString TabularTable::getCellRangeText(int row,int col1, int col2)
+{
+	QString s;
+	for ( int col=col1; col<=col2; ) 
+	{
+		TabularItem *cellitem = dynamic_cast<TabularItem*>( item(row,col) );
+		if ( cellitem ) 
+		{
+			s += cellitem->text();
+			col += cellitem->colSpan();
+		}
+		else
+		{
+			col++;
+		}
+	}
+	return s;
+}
 
 ////////////////////////////// header: right mouse button //////////////////////////////
 
@@ -1895,7 +1955,7 @@ void TabularDialog::initEnvironments(bool tabularenv)
 
 void TabularDialog::slotEnvironmentChanged(const QString &env)
 {
-	kdDebug() << "env changed " << env << endl;
+	//kdDebug() << "env changed " << env << endl;
 	
 	// clear parameter combobox
 	m_coParameter->clear();
@@ -1937,7 +1997,7 @@ bool TabularDialog::isMathmodeEnvironment(const QString &env)
 
 void TabularDialog::slotRowValueChanged(int value)
 {
-	kdDebug() << "row value changed " << value << endl;
+	//kdDebug() << "row value changed " << value << endl;
 	
 	bool askBeforeDelete = m_cbWarning->isChecked();
 	bool firstwarning = true;
